package com.ruoyi.ai.service.impl;

import java.util.List;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.ai.mapper.AiBannerMapper;
import com.ruoyi.ai.domain.AiBanner;
import com.ruoyi.ai.service.IAiBannerService;

/**
 * banner管理Service业务层处理
 * 
 * @author shi
 * @date 2025-11-13
 */
@Service
public class AiBannerServiceImpl implements IAiBannerService {

    @Autowired
    private AiBannerMapper aiBannerMapper;

    /**
     * 查询banner管理
     * 
     * @param id banner管理主键
     * @return banner管理
     */
    @Override
    public AiBanner selectAiBannerById(Long id) {
        return aiBannerMapper.selectById(id);
    }

    /**
     * 查询banner管理列表
     * 
     * @param aiBanner banner管理
     * @return banner管理
     */
    @Override
    public List<AiBanner> selectAiBannerList(AiBanner aiBanner) {
        return aiBannerMapper.selectAiBannerList(aiBanner);
    }

    /**
     * 分页查询banner管理列表
     *
     * @param aiBanner banner管理
     * @return banner管理
     */
    @Override
    public IPage<AiBanner> selectAiBannerPage(Page page, AiBanner aiBanner) {
        LambdaQueryWrapper<AiBanner> query = Wrappers.lambdaQuery(aiBanner);
        query.eq(AiBanner::getDelFlag, "0");
        return aiBannerMapper.selectPage(page, query);
    }

    /**
     * 新增banner管理
     * 
     * @param aiBanner banner管理
     * @return 结果
     */
    @Override
    public int insertAiBanner(AiBanner aiBanner) {
        aiBanner.setDelFlag("0");
        aiBanner.setCreateBy(SecurityUtils.getUsername());
        aiBanner.setCreateTime(DateUtils.getNowDate());
        return aiBannerMapper.insert(aiBanner);
    }

    /**
     * 修改banner管理
     * 
     * @param aiBanner banner管理
     * @return 结果
     */
    @Override
    public int updateAiBanner(AiBanner aiBanner) {
        aiBanner.setUpdateBy(SecurityUtils.getUsername());
        aiBanner.setUpdateTime(DateUtils.getNowDate());
        return aiBannerMapper.updateById(aiBanner);
    }

    /**
     * 批量删除banner管理
     * 
     * @param ids 需要删除的banner管理主键
     * @return 结果
     */
    @Override
    public int deleteAiBannerByIds(Long[] ids)
    {
        return aiBannerMapper.deleteAiBannerByIds(ids);
    }

    /**
     * 删除banner管理信息
     * 
     * @param id banner管理主键
     * @return 结果
     */
    @Override
    public int deleteAiBannerById(Long id)
    {
        return aiBannerMapper.deleteAiBannerById(id);
    }
}
